import {Component, ElementRef, ViewChild} from '@angular/core';
import {ConfigurationCardComponent} from "@component/admin/configuration-card/configuration-card.component";
import {MatDialog} from "@angular/material/dialog";
import {
  ConfirmDeleteScheduleDialogComponent
} from "@component/admin/confirm-delete-schedule-dialog/confirm-delete-schedule-dialog.component";
import {Observable, switchMap} from "rxjs";
import {MatButtonModule} from "@angular/material/button";
import {MatIcon} from "@angular/material/icon";
import {ScheduleService} from "@api/v1/configuration/schedule.service";
import {DataSpinnerComponent} from "@component/common/data-spinner/data-spinner.component";
import {MatFormFieldModule} from "@angular/material/form-field";
import {FormsModule} from "@angular/forms";
import {MatInput} from "@angular/material/input";
import {ToastrService} from "ngx-toastr";

@Component({
  selector: 'app-schedule-file-upload',
  imports: [
    ConfigurationCardComponent,
    MatButtonModule,
    MatIcon,
    DataSpinnerComponent,
    MatFormFieldModule,
    FormsModule,
    MatInput
  ],
  templateUrl: './schedule-file-upload.component.html',
  providers: [ScheduleService]
})
export class ScheduleFileUploadComponent {
  selectedFiles: { file: File, campus: string }[] = [];
  fileLoading: boolean = false;
  @ViewChild('fileInput') input!: ElementRef;

  constructor(private dialog: MatDialog, private api: ScheduleService, private notify: ToastrService) {
  }

  protected saveFunction() {
    return () => {
      const dialogRef = this.dialog.open(ConfirmDeleteScheduleDialogComponent);

      return dialogRef.afterClosed().pipe(switchMap(result => {
        return this.api.uploadScheduleFile(
          this.selectedFiles.map(x => x.file),
          this.selectedFiles.map(x => x.campus),
          result);
      }));
    };
  }

  onFileChooseClick() {
    this.fileLoading = true;
    this.input.nativeElement.click();
  }

  onFileSelected(event: any): void {
    this.fileLoading = false;
    this.selectedFiles = Array.from(event.target.files)
      .map(x => <{file: File, campus: string}>{file: x, campus: ''});
  }

  onUpload(data: Observable<any>): void {
    data.subscribe(_ => {
      this.notify.info(`Файлы в размере ${this.selectedFiles.length} успешно загружены. Задача поставлена в очередь`);
      this.selectedFiles = [];
    });
  }
}
